@@ -17,7 +17,7 @@ class SQLCommands(object):
         async with aiosqlite.connect(self._database_name) as db:
             async with db.cursor() as cursor:
                 await cursor.execute(
-                    f"DELETE FROM {self._table_name} WHERE {self._primary_key} = ?", (row_id, ))
+                    f"DELETE FROM {self._table_name} WHERE {self._primary_key} = ?", (row_id,))
             await db.commit()
 
     async def execute(self, query):
@@ -53,10 +53,17 @@ class Connect(SQLCommands):
         async with aiosqlite.connect(self._database_name) as db:
             async with db.cursor() as cursor:
                 data = {}
-                columns = ""
-                for column in column_names:
-                    columns += column + ", "
-                columns = columns[:-2]  # Remove the ", " at the end
+                columns = ", ".join(column for column in column_names)
+
+                def check_type(value, value_type):
+                    # to check if value is of certain type
+                    try:
+                        val = str(value)
+                        return isinstance(literal_eval(val), value_type)
+                    except SyntaxError:
+                        return False
+                    except ValueError:
+                        return False
 
                 if columns == "*":
                     getID = await cursor.execute(
@@ -65,13 +72,12 @@ class Connect(SQLCommands):
                     values = await getID.fetchone()
                     values = list(values)
                     for v in range(len(values)):
-                        if str(values[v]).startswith("[") or str(values[v]).startswith("{") or str(values[v]).startswith("("):
-                            try:
+                        if not (isinstance(values[v], int) or isinstance(values[v], float)):
+                            isList = check_type(values[v], list)
+                            isTuple = check_type(values[v], tuple)
+                            isDict = check_type(values[v], dict)
+                            if isList or isTuple or isDict:
                                 values[v] = literal_eval(values[v])
-                            except Exception as e:
-                                raise Exception(e)
-                        else:
-                            continue
                     for i in range(len(fieldnames)):
                         data[fieldnames[i]] = values[i]
                     return data
@@ -81,13 +87,12 @@ class Connect(SQLCommands):
                     values = await getID.fetchone()
                     values = list(values)
                     for v in range(len(values)):
-                        if str(values[v]).startswith("[") or str(values[v]).startswith("{") or str(values[v]).startswith("("):
-                            try:
+                        if not (isinstance(values[v], int) or isinstance(values[v], float)):
+                            isList = check_type(values[v], list)
+                            isTuple = check_type(values[v], tuple)
+                            isDict = check_type(values[v], dict)
+                            if isList or isTuple or isDict:
                                 values[v] = literal_eval(values[v])
-                            except Exception as e:
-                                raise Exception(e)
-                        else:
-                            continue
                     for i in range(len(column_names)):
                         data[column_names[i]] = values[i]
                     return data
@@ -106,24 +111,25 @@ class Connect(SQLCommands):
         """
         async with aiosqlite.connect(self._database_name) as db:
             async with db.cursor() as cursor:
-                getUser = await cursor.\
-                    execute(f"SELECT {self._primary_key} FROM {self._table_name} WHERE {self._primary_key} = ?", (my_id,))
+                getUser = await cursor. \
+                    execute(f"SELECT {self._primary_key} FROM {self._table_name} WHERE {self._primary_key} = ?",
+                            (my_id,))
                 isUserExists = await getUser.fetchone()
                 if isUserExists:
                     for key, val in dictionary.items():
-                        if str(val).startswith("[") or str(val).startswith("{") or str(val).startswith("("):
-                            val = str(val)
-                        else:
-                            pass
-                        await cursor.execute(f"UPDATE {self._table_name} SET {key} = ? WHERE {self._primary_key} = ?", (val, my_id,))
+                        if isinstance(val, list) or isinstance(val, dict) or isinstance(val, tuple):
+                            dictionary[key] = str(val)
+                    await cursor.execute(f"UPDATE {self._table_name} SET " + ', '.join(
+                        "{}=?".format(k) for k in dictionary.keys()) + f" WHERE {self._primary_key}=?",
+                                         list(dictionary.values()) + [my_id])
                 else:
                     await cursor.execute(f"INSERT INTO {self._table_name} ({self._primary_key}) VALUES ( ? )", (my_id,))
                     for key, val in dictionary.items():
-                        if str(val).startswith("[") or str(val).startswith("{") or str(val).startswith("("):
-                            val = str(val)
-                        else:
-                            pass
-                        await cursor.execute(f"UPDATE {self._table_name} SET {key} = ? WHERE {self._primary_key} = ?", (val, my_id,))
+                        if isinstance(val, list) or isinstance(val, dict) or isinstance(val, tuple):
+                            dictionary[key] = str(val)
+                    await cursor.execute(f"UPDATE {self._table_name} SET " + ', '.join(
+                        "{}=?".format(k) for k in dictionary.keys()) + f" WHERE {self._primary_key}=?",
+                                         list(dictionary.values()) + [my_id])
 
             await db.commit()
 
@@ -171,10 +177,10 @@ class Connect(SQLCommands):
                 if like is not None and condition is False:
                     condition = True
                     query += f" WHERE {column_name} LIKE ?"
-                    parameters.append("%"+like+"%")
+                    parameters.append("%" + like + "%")
                 elif like is not None and condition is True:
                     query += f" AND {column_name} LIKE ?"
-                    parameters.append("%"+like+"%")
+                    parameters.append("%" + like + "%")
                 if between is not None and condition is False:
                     condition = True
                     query += f" WHERE {column_name} BETWEEN ? AND ?"
@@ -186,8 +192,7 @@ class Connect(SQLCommands):
                     parameters.append(range(between[0], between[1]).start)
                     parameters.append(range(between[0], between[1]).stop)
                 if order_by is not None:
-                    query += f" ORDER BY ?"
-                    parameters.append(order_by.strip("'"))
+                    query += f" ORDER BY {order_by}"
                 if ascending is False:
                     query += f" DESC"
                 else:
@@ -201,18 +206,20 @@ class Connect(SQLCommands):
                 elif offset is not None and limit is None:
                     raise Exception("You can't use kwarg 'offset' without kwarg 'limit'")
                 parameters = str(tuple(parameters))
-                parameters = parameters[:-1] + ")"
-                parameters = literal_eval(parameters)
+                parameters = eval(parameters)
                 # print(f"query ==> await cursor.execute(\"{query}\", {parameters})")
                 # print(parameters)
                 getValues = await cursor.execute(query, parameters)
                 values = await getValues.fetchall()
                 my_list = []
 
-                def isfloat(num):
+                def check_type(value, value_type):
+                    # to check if value is of certain type
                     try:
-                        float(num)
-                        return True
+                        val = str(value)
+                        return isinstance(literal_eval(val), value_type)
+                    except SyntaxError:
+                        return False
                     except ValueError:
                         return False
 
@@ -222,11 +229,11 @@ class Connect(SQLCommands):
                     # Check the type of i
                     if i.isnumeric():
                         my_list.append(int(i))
-                    elif isfloat(i):
+                    elif isinstance(i, float):
                         my_list.append(float(i))
                     elif i == 'None' or i is None:
                         my_list.append(i)
-                    elif i.startswith("'[") or i.startswith("'{") or i.startswith("'("):
+                    elif check_type(i, list) or check_type(i, dict) or check_type(i, tuple):
                         i = eval(i)
                         my_list.append(eval(i))
                     elif i.isascii():
